CrudTableDataModel<T> class

Constructors

CrudTableDataModel({bool? isError, bool? isLoading, List<T>? data})

Properties

data ↔ List<T>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isError ↔ bool?
getter/setter pair
isLoading ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited